<?php
namespace Teknisa\MAN\Controllers;

use Teknisa\MAN\Services\CadastramentosAutomaticoService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error; 
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\XLS\Exception;

use Teknisa\MAN\Controllers\TeknisaCrud;

class CadastramentosAutomaticoController extends TeknisaCrud {
    
    public function __construct($crudService, ParameterBag $parameterBag, CadastramentosAutomaticoService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }
    
    public function importXls(DTO\Request $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $table = $this->service->readXls($row);
            $rows = $this->service->formatXls($table);
            $response->addDataSet(new DataSet('import', $rows));
        }
        catch(Exception $e){
            $errors = $e->getErrors();
            $response->addDataSet(new DataSet('errors', $errors));
            $response->setError(new Error($e->getMessage(), 500));
        }
        catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function salveCampos(DTO\Request $request, DTO\Response $response){
        try{
            $dataSet = $request->getRow();
            $validCampos = $this->service->validCampos($dataSet);
            if($validCampos['operacao']){
                $salveRows = $this->service->salveCampos($dataSet);
                if($salveRows['operacao']){
                    if(isset($salveRows['error']) && (is_array($salveRows['error']) ? count($salveRows['error']) > 0 : 0)){
                        $rows = array (
                            "operacao" => true,
                            "message" => "Rotina finalizada com sucesso, nem todos dados foram inseridos! Verifique aba de Validação",
                            "errors" => $salveRows['error']
                        );
                    }else{
                        $rows = array (
                            "operacao" => true,
                            "message" => "Dados salvos com sucesso"
                        );
                    }
                }else{
                    $rows = array (
                        "operacao" => $salveRows['operacao'],
                        "message" => $salveRows['error']
                    );
                }
            }else{
                $rows = array (
                    "operacao" => $validCampos['operacao'],
                    "errors" => $validCampos['errors'],
                    "message" => "Erro ao validar os dados do arquivo"
                );
            }
            $response->addDataSet(new DataSet('import', $rows));
        }
        catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
}