<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\RelatorioService;
use Teknisa\MAN\Services\RelSinteseFaturamento;

class RelFaturamentoDelivery extends CrudWithParameterBag {
    
    const RELATORIO_GERAL_NAME   = 'vnd55000_relFaturamentoDeliveryGeral',
          RELATORIO_POR_DIA_NAME = 'vnd55001_relFaturamentoDeliveryPorDia';
    
    protected $utilService, 
              $relatorioService;

    public function __construct (Utilities\Util $utilService, RelatorioService $relatorioService, RelSinteseFaturamento $relSinteseFaturamento) {
      
        $this->utilService = $utilService;
        $this->relatorioService = $relatorioService;
        $this->relSinteseFaturamento = $relSinteseFaturamento;
    }
    
    public function findGeral(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        $modalidades = 'DLV_SAT_DLV_FOS_DLV_APP_DLV_CAL_DLV_IFO_DLV_OUT_DLV_PJA_DLV_SIT_DLV_INT_DLV_SPO_DLV_FNC_DLV_IOS_DLV_ADR_DLV_TAA_DLV_ABF_DLV_ONY_DLV_WZP_DLV_UBR_DLV_YAN_DLV_RAP';
        $conditions = $this->relSinteseFaturamento->buildParamsFaturamento($conditions, $modalidades);
            
        if($conditions['TIPORELATORIO'] == 'A') {
            $result = $this->relSinteseFaturamento->findFaturamentoDeliveryAnaliticoGeral($conditions); 
        } else if($conditions['TIPORELATORIO'] == 'S'){
            $result = $this->relSinteseFaturamento->findFaturamentoDeliverySinteticoGeral($conditions);
        }
        
        $response->addDataSet(new DataSet(SELF::RELATORIO_GERAL_NAME, $result));
        return $response;
    }
    
    public function findPorDia(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        $modalidades = 'DLV_SAT_DLV_FOS_DLV_APP_DLV_CAL_DLV_IFO_DLV_OUT_DLV_PJA_DLV_SIT_DLV_INT_DLV_SPO_DLV_FNC_DLV_IOS_DLV_ADR_DLV_TAA_DLV_ABF_DLV_ONY_DLV_WZP_DLV_UBR_DLV_YAN_DLV_RAP';
        $conditions = $this->relSinteseFaturamento->buildParamsFaturamento($conditions, $modalidades);
        
        if($conditions['TIPORELATORIO'] == 'A') {
            $result = $this->relSinteseFaturamento->findFaturamentoDeliveryAnaliticoDia($conditions);
        } else if($conditions['TIPORELATORIO'] == 'S'){
            $result = $this->relSinteseFaturamento->findFaturamentoDeliverySinteticoDia($conditions);
        }
                
        if($result) {
            $result = $this->relSinteseFaturamento->reorderResultsbyDate($result);
        }
        
        $response->addDataSet(new DataSet(SELF::RELATORIO_POR_DIA_NAME, $result));
        return $response;    
        
    }
}

