<?php

namespace Teknisa\MAN\Services;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;
use \Setforms2\Shared\ORM\DateTime;

class RelCustoComposicaoProduto {
	
	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	public function getTipoImposto($CDFILIAL, $NRORG){
		$params = array( 
			':CDFILIAL'=> $CDFILIAL,
			':NRORG'   => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(Utilities\Query::TIPO_IMPOSTO, $params);
	}
	
	public function getTabPrec($NRORG, $CDFILIAL, $CDLOJA ){
		$params = array( 
			':CDFILIAL'=> $CDFILIAL,
			':CDLOJA'  => $CDLOJA,
			':NRORG'   => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAssoc(self::GET_TAB_PREC, $params);
	}
	
	public function getProdTabGeral($CDTABPREC, $CDPRODINI, $CDPRODFIN, $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV){
		
		$params = array( 
			
			':CDTABEPREC' => $CDTABPREC,
			':CDPRODINI'  => $CDPRODINI,
			':CDPRODFIN'  => $CDPRODFIN,
			':CDPRODLIST'  => $CDPRODLIST,
			':PRODNIV'   => $PRODNIV,
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(self::GET_PROD_PAI_GERAL, $params);
	}
	
	public function getProdPaiPadrao($CDTABPREC, $CDPRODINI, $CDPRODFIN, $CDFILIAL, $NRORG, $CDPRODLIST, $PRODNIV){
		$params = array( 
			':CDTABEPREC' => $CDTABPREC,
			':CDPRODINI'  => $CDPRODINI,
			':CDPRODFIN'  => $CDPRODFIN,
			':CDPRODLIST'  => $CDPRODLIST,
			':PRODNIV'   => $PRODNIV,
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		
		return $this->entityManager->getConnection()->fetchAll(self::GET_PROD_PAI_PADRAO, $params);
	}
	
	public function getInstr($CDFILIAL, $CDPRODUTO, $NRORG, $PADRAO_LOCAL){
		$params = array( 
			':CDFILIAL'   => $CDFILIAL,
			':CDPRODUTO'  => $CDPRODUTO,
			':NRORG'      => $NRORG
		);
		$INSTR = ($PADRAO_LOCAL == 'P' ? $this->entityManager->getConnection()->fetchAll(self::GET_INSTR_P, $params):$this->entityManager->getConnection()->fetchAll(self::GET_INSTR_L, $params));
		return $INSTR; 
	}
	
	public function procedureCustoCompProd($row, $aux) {
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'CUSTO_COMP_PROD');
        $procedure->addParam(new Param('P_CDPRODUTO', Param::PARAM_INPUT, $aux['CDPRODUTO'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT,  $row['CDFILIAL'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FILIPROC', Param::PARAM_INPUT,  $row["CDFILIAL"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_TIPOCUSTO', Param::PARAM_INPUT, str_replace('%', '',$row['NMTIPOCUSTO']), Param::PARAM_TYPE_INT)); 
        $procedure->addParam(new Param('P_QTPRODUTO', Param::PARAM_INPUT, 1 , Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_LOJA', Param::PARAM_INPUT,    $row['CDLOJA'] , Param::PARAM_TYPE_STR)); 
        $procedure->addParam(new Param('P_VRCUSTO', Param::PARAM_OUTPUT,  null, Param::PARAM_TYPE_STR, 50));
        $retorno = $procedure->execute();
        $retorno = floatval($retorno['P_VRCUSTO']);
        return $retorno;
    }
    
    public function getLabelFilial($CDFILIAL, $CDLOJA, $NRORG){
		$params = array( 
			':CDFILIAL'   => $CDFILIAL,
			':CDLOJA'     => $CDLOJA,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAssoc(self::GET_LABEL_FILIAL, $params);
	}
	
    public function getGrupoProd( $NRORG, $CDFILIAL){
		$params = array( 
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(self::GET_GRUPO_PRODUTO, $params);
	}
	
	public function getComposicaoProduto( $CDPRODUTO, $NRORG, $ARRAY, $CDCOMPOSICAO, $CDFILIAL, $CDPRODUTOPAI){
		$params = array( 
			':CDPRODUTO'   => $CDPRODUTO,
			':NRORG'       => $NRORG,
			':CDFILIAL'	   => $CDFILIAL,
			':CDPRODUTOAVO'=> $CDPRODUTOPAI
		);
		if($CDCOMPOSICAO == 'P'){
			$ARRAYCOMPOSICAO = $this->entityManager->getConnection()->fetchAll(self::GET_COMPOSICAO_PRODUTO, $params);
		} else {
			$ARRAYCOMPOSICAO = $this->entityManager->getConnection()->fetchAll(self::GET_COMPOSICAO_PRODUTO_LOCAL, $params);
		}
		array_push($ARRAY, $ARRAYCOMPOSICAO);
		return $ARRAY;
		
	}
	
	public function getComposicaoTodosProdutos( $CDPRODUTO, $NRORG, $ARRAY, $CDCOMPOSICAO, $CDFILIAL,  $CDPRODUTOPAI){
		$params = array( 
			':CDPRODUTO'   => $CDPRODUTO,
			':NRORG'       => $NRORG,
			':CDFILIAL'	   => $CDFILIAL,
			':CDPRODUTOAVO'=> $CDPRODUTOPAI
		);
		
		if($CDCOMPOSICAO == 'P'){
			$ARRAYCOMPOSICAO = $this->entityManager->getConnection()->fetchAll(self::GET_COMPOSICAO_PRODUTO, $params);
		} else {
			$ARRAYCOMPOSICAO = $this->entityManager->getConnection()->fetchAll(self::GET_COMPOSICAO_PRODUTO_LOCAL, $params);
		}
			//$ARRAYCOMPOSICAO['CDPRODUTOAVO'] = $CDPRODUTOPAI;
			array_push($ARRAY, $ARRAYCOMPOSICAO);
			foreach ($ARRAYCOMPOSICAO as $value) {
				$x = $this->getComposicaoTodosProdutos($value['CDPRODUTO'], $NRORG, [], $CDCOMPOSICAO, $CDFILIAL, $CDPRODUTOPAI);
				if(!!$x[0]){
					foreach ($x[0] as $produto) {
						array_push($ARRAY[0], $produto);
						
					}
				}
			}	
			
			
		return $ARRAY;
	}	
	
	public function getNameProduct ($CDPRODUTO, $NRORG){
		$paramsNomeProduto = array( 
					':CDPRODUTO'   => $CDPRODUTO,
					':NRORG'       => $NRORG
				);
		$NAME = $this->entityManager->getConnection()->fetchAssoc(self::GET_NAME_PRODUCT, $paramsNomeProduto);
		return $NAME['NMPRODUTO'];
	}	
	
	public function getPrecoItem($NRORG, $CDFILIAL, $CDPRODUTO, $CDTABPREC, $DATAATUAL){
		$params = array( 
			':CDPRODUTO'  => $CDPRODUTO,
			':CDTABEPREC' => $CDTABPREC,
			':DATAHOJE'   => $DATAATUAL,	
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAssoc(self::GET_PRECO_ITEM, $params);
	}
	
	public function getCumuPisCoFil($NRORG, $CDFILIAL){
		$params = array(	
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAssoc(self::GET_CUMUPISCOFIL, $params);
	}
	
	public function getAliqPisConfins($NRORG, $CDFILIAL, $CDPRODUTO){
		$params = array(	
			':CDPRODUTO'   => $CDPRODUTO,
			':CDFILIAL'   => $CDFILIAL,
			':NRORG'      => $NRORG
		);
		return $this->entityManager->getConnection()->fetchAssoc(self::GET_ALIQPISCONFIS, $params);
	}
	
	public function getProdutoAdc($CDPRODUTO, $NRORG, $CDFILIAL, $CDPRODUTOPAI){
		$params = array(	
			':CDPRODUTO'   => $CDPRODUTO,
			':CDFILIAL'    => $CDFILIAL,
			':NRORG'       => $NRORG,
			':CDPRODUTOPAI'=> $CDPRODUTOPAI
		);
		return $this->entityManager->getConnection()->fetchAll(self::GET_PRODUTO_ADICIONAL, $params);
	}
	
	public function getCompPadrLoc($conditions){
		$params = array(
			':CDFILIAL' 	=> $conditions['CDFILIAL'],
			':CDPRODLIST'	=> array_key_exists('CDPRODLIST', $conditions) ? $conditions['CDPRODLIST'] : NULL,
			':CDPRODINI'	=> $conditions['CDPRODINI'],
			':CDPRODFIN'	=> $conditions['CDPRODFIN'],
			':PRODNIV'  	=> $conditions['PRODNIV'],
			':TCDPRODUTO'	=> array_key_exists('TCDPRODUTO', $conditions) ? $conditions['TCDPRODUTO'] : NULL,
			':NRORG'	    => $conditions['NRORG']
		);
		
		return $this->entityManager->getConnection()->fetchAll(self::GET_COMPARATIVO_PADRAO_LOCAL, $params);
	}
	
	
	
const GET_TAB_PREC = "
	SELECT LO.CDTABEPREC AS TABLOJA, PA.CDTABEPREC AS TABPADRAO, GER.CDTABEPREC AS TABGERAL
	FROM LOJA LO, PARAVEND PA, FILITABGER GER
	WHERE LO.CDFILIAL = :CDFILIAL
	AND LO.CDLOJA = :CDLOJA
	AND PA.CDFILIAL = LO.CDFILIAL
	AND GER.CDFILIAL (+) = PA.CDFILIAL 
	AND GER.CDFILIAL (+) = LO.CDFILIAL
	";
	 
	const GET_PROD_PAI_PADRAO = "
        SELECT DISTINCT I.CDFILIAL, F.NMFILIAL, I.CDFILIAL||' - '||F.NMFILIAL AS LABELFILIAL, PR.CDPRODUTO, PR.CDARVPROD, PR.NMPRODUTO, 
               PR.SGUNIDADE, PR.CDARVPROD || ' - ' || PR.NMPRODUTO AS LABELPRODUTO
        FROM PRODUTO PR
        JOIN ITEMPRECO I
          ON PR.CDPRODUTO = I.CDPRODUTO
         AND PR.NRORG = I.NRORG
        JOIN TABEVEND T
          ON I.CDFILIAL = T.CDFILIAL
         AND I.CDTABEPREC = T.CDTABEPREC
         AND I.DTINIVGPREC = T.DTINIVGPREC
         AND I.NRORG = T.NRORG
        JOIN FILIAL F
          ON F.CDFILIAL = T.CDFILIAL
         AND F.NRORG = T.NRORG
       WHERE (I.CDFILIAL   = :CDFILIAL)
         AND (I.CDTABEPREC = :CDTABEPREC)
         AND (SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC)
         AND (NVL(VRPRECITEM,0) <> 0 OR NVL(VRPRECITEMCL,0) <> 0 )
         AND (PR.CDNVPRODUTO = (SELECT MAX(CDNVPRODUTO) FROM PRODUTO))
         AND ((((INSTR(:CDPRODLIST, PR.CDPRODUTO) > 0 ) OR (PR.CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN ))) OR (PR.CDARVPROD LIKE :PRODNIV))
         AND (PR.NRORG =  :NRORG)
       ORDER BY CDARVPROD
	";
	
	const GET_PROD_PAI_GERAL = "
	 SELECT DISTINCT F.CDFILIAL, F.NMFILIAL, F.CDFILIAL||' - '||F.NMFILIAL AS LABELFILIAL, PR.CDPRODUTO, PR.CDARVPROD, PR.NMPRODUTO, 
               PR.SGUNIDADE, PR.CDARVPROD || ' - ' || PR.NMPRODUTO AS LABELPRODUTO
        FROM PRODUTO PR
        JOIN ITEMPRECOGER I
          ON PR.CDPRODUTO = I.CDPRODUTO
         AND PR.NRORG = I.NRORG
        JOIN TABEVENDGER T              
         ON I.DTINIVGPREC = T.DTINIVGPREC
         AND T.CDTABEPREC = I.CDTABEPREC
         AND I.NRORG = T.NRORG
         JOIN FILITABGER TG         
         ON TG.NRORG = T.NRORG         
        JOIN FILIAL F
          ON F.CDFILIAL = TG.CDFILIAL
         AND F.NRORG = T.NRORG
       WHERE (F.CDFILIAL   = :CDFILIAL)
         AND (I.CDTABEPREC = :CDTABEPREC)
         AND (SYSDATE BETWEEN T.DTINIVGPREC AND T.DTFINVGPREC)
         AND (NVL(VRPRECITEM,0) <> 0 OR NVL(VRPRECITEMCL,0) <> 0 )
         AND (PR.CDNVPRODUTO = (SELECT MAX(CDNVPRODUTO) FROM PRODUTO))
         AND ((((INSTR(:CDPRODLIST, PR.CDPRODUTO) > 0 ) OR (PR.CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN ))) OR (PR.CDARVPROD LIKE :PRODNIV))
         AND (PR.NRORG =  :NRORG)
       ORDER BY CDARVPROD
       
	";
	   
	const GET_INSTR_P = "
		SELECT CDPRODUTO, TXROTFAB       
		  FROM DESCROTEIRO
		 WHERE (CDPRODUTO =  :CDPRODUTO) 
		   AND (NRORG =  :NRORG)
	";
	   
	 const GET_INSTR_L ="
		   SELECT
		   CDFILIAL,
		   CDPRODUTO,
		   TXROTFABLOC
		FROM
		   DESCROTLOCAL
		WHERE
		   (CDFILIAL = :CDFILIAL) AND
		   (CDPRODUTO =  :CDPRODUTO) AND
		   (NRORG =  :NRORG)";
	   
	  const GET_GRUPO_PRODUTO = "
		SELECT
		   P.CDLOJA, P.CDGRPRODPDV,
		   G.CDGRUPPROD||' - '||G.NMGRUPPROD AS GRUPOPROD
		FROM
		   PARAVEND P
		   LEFT JOIN GRUPPROD G ON
		   (P.CDGRPRODPDV = G.CDGRUPPROD)
		WHERE
		   (P.CDFILIAL    = :CDFILIAL) AND
		   (P.NRORG 	  = :NRORG) AND
		   (G.NRORG 	  = :NRORG)
	  "; 
	  
	  const GET_COMPOSICAO_PRODUTO = "
	     SELECT
		   RB.CDPRODUTO AS CDPRODUTOPAI, PAI.NMPRODUTO AS NMPRODUTOPAI,  RB.CDSUBPRODUTO AS CDPRODUTO,  PT.CDARVPROD, RB.QTSUBPRODROT,
		   RB.NRHRFABPROD, RB.NRSEQPROD, RB.IDIMPPRODROT,  RB.CDPRODUTO || ' - ' || PAI.NMPRODUTO AS LABELPRODUTOPAI,
		   'Produto sem itens adicionais' AS NMMODOVENDA, :CDPRODUTOAVO || ' - ' || AVO.NMPRODUTO AS AVO,
           RB.CDSUBPRODUTO || ' - ' || PT.NMPRODUTO AS LABELPRODUTO, :CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,
		   PT.NMPRODUTO,  PT.SGUNIDADE,  DR.TXROTFAB as TXINSTR, :NRORG AS NRORG
		FROM
		   ROTFABRICA RB   
		  JOIN PRODUTO PT ON
		   RB.CDSUBPRODUTO = PT.CDPRODUTO AND
		   RB.NRORG = PT.NRORG
		  LEFT JOIN DESCROTEIRO DR ON 
		   RB.CDPRODUTO    = DR.CDPRODUTO AND
		   RB.NRORG = DR.NRORG
        JOIN PRODUTO PAI ON
		       PAI.CDPRODUTO = RB.CDPRODUTO AND
		       PAI.NRORG = RB.NRORG
		JOIN PRODUTO AVO ON
		       AVO.CDPRODUTO = :CDPRODUTOAVO AND
		       AVO.NRORG = RB.NRORG       
        JOIN FILIAL F ON 
           F.CDFILIAL = :CDFILIAL AND
           F.NRORG = :NRORG
		 WHERE RB.CDPRODUTO    = :CDPRODUTO
		   AND RB.NRORG = :NRORG
	  ";
	  
	  const GET_COMPOSICAO_PRODUTO_LOCAL = "
	   SELECT
		   RL.CDFILIAL, RL.CDPRODUTO AS CDPRODUTOPAI,  PAI.NMPRODUTO AS NMPRODUTOPAI, RL.CDSUBPRODLOC AS CDPRODUTO,
		   PT.CDARVPROD,  RL.CDPRODUTO || ' - ' || PAI.NMPRODUTO AS LABELPRODUTOPAI,
		   'Produto sem itens adicionais' AS NMMODOVENDA,
		   RL.QTSUBPRODLOC AS QTSUBPRODROT,  :CDPRODUTOAVO || ' - ' || AVO.NMPRODUTO AS AVO,
		   RL.CDSUBPRODLOC || ' - ' || PT.NMPRODUTO AS LABELPRODUTO, 
		   :CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,
		   RL.NRHRFABPRLOC AS NRHRFABPROD, RL.IDIMPPROTLOC AS IDIMPPRODROT,
		   :NRORG AS NRORG,
		   RL.NRSEQPRODLOC AS NRSEQPROD,
		   PT.NMPRODUTO, PT.SGUNIDADE,
		   DL.TXROTFABLOC AS TXINSTR
		FROM
		   ROTFABLOCAL RL
		  JOIN PRODUTO PT ON
		   (RL.CDSUBPRODLOC = PT.CDPRODUTO) AND
		   (RL.NRORG = PT.NRORG)
		  LEFT JOIN DESCROTLOCAL DL ON
		   (RL.CDFILIAL  = DL.CDFILIAL)  AND
		   (RL.CDPRODUTO   = DL.CDPRODUTO) AND
		   (RL.NRORG = DL.NRORG)
		  JOIN PRODUTO PAI ON
		    PAI.CDPRODUTO = RL.CDPRODUTO AND
		    PAI.NRORG = RL.NRORG
		  JOIN PRODUTO AVO ON
		    AVO.CDPRODUTO = :CDPRODUTOAVO AND
		    AVO.NRORG = RL.NRORG  
		  JOIN FILIAL F ON 
            F.CDFILIAL = :CDFILIAL AND
            F.NRORG = :NRORG  
		WHERE   
		   (RL.CDFILIAL     = :CDFILIAL)  AND
		   (RL.CDPRODUTO    = :CDPRODUTO) AND
		   (RL.NRORG		= :NRORG)
		   ";
		   
	   const GET_PRECO_ITEM = "
	   SELECT
		   I.VRPRECITEM
		FROM 
		   ITEMPRECO I, TABEVEND T
		WHERE 
		   (I.CDFILIAL     = :CDFILIAL  ) AND
		   (I.CDPRODUTO    = :CDPRODUTO ) AND
		   (I.CDTABEPREC   = :CDTABEPREC) AND
		   (I.CDFILIAL     = T.CDFILIAL   ) AND
		   (I.CDTABEPREC   = T.CDTABEPREC ) AND
		   (I.DTINIVGPREC  = T.DTINIVGPREC) AND
		   (T.DTINIVGPREC <= :DATAHOJE ) AND
		   (T.DTFINVGPREC >= :DATAHOJE ) AND
		   (T.NRORG 	   = :NRORG ) AND
		   (I.NRORG        = :NRORG )
	   ";
	   
	   const GET_CUMUPISCOFIL = "
	   SELECT
		   IDCUMUPISCOFIL
		FROM
		   FILIAL
		WHERE
		   (CDFILIAL = :CDFILIAL) AND 
		   (NRORG    = :NRORG)
	   ";
	   
	   const GET_ALIQPISCONFIS = "
	   SELECT
		   VRPEALIMPFIS, IDINCIDEPISCOF
		FROM
		   ALIQIMPFIS
		WHERE
		   (CDFILIAL  = :CDFILIAL ) AND
		   (CDPRODUTO = :CDPRODUTO) AND 
		   (NRORG	  = :NRORG	  )";
		   
		const GET_NAME_PRODUCT = "
		SELECT NMPRODUTO 
		FROM
			PRODUTO 
		WHERE 
			CDPRODUTO = :CDPRODUTO AND
			NRORG = :NRORG
		
		";   
		
		const GET_LABEL_FILIAL = "
		SELECT F.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL
		FROM FILIAL F 
	    WHERE F.CDFILIAL = :CDFILIAL AND
	          F.NRORG = :NRORG
	    ";
	    
	    const GET_PRODUTO_ADICIONAL = "
		    SELECT A.CDPRODUTO AS CDPRODUTOPAI, A.CDSUBPRODUTO AS CDPRODUTO, A.IDMODOVENDA,
			       A.CDSUBPRODUTO || ' - ' || P.NMPRODUTO AS LABELPRODUTO,
			       A.CDPRODUTO    || ' - ' || PAI.NMPRODUTO AS LABELPRODUTOPAI,
			       :CDPRODUTOPAI  || ' - ' || AVO.NMPRODUTO AS AVO,
			       :CDFILIAL      || ' - ' || F.NMFILIAL AS LABELFILIAL,
		    CASE A.IDMODOVENDA WHEN 'BAL' THEN 'Balcão'  WHEN 'CMD' THEN 'Comanda' 
		        WHEN 'DLV' THEN 'Delivery' WHEN 'MES' THEN 'Mesa' END AS NMMODOVENDA, 
		        A.QTPRODADIC AS QTSUBPRODROT, P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE
			 FROM PRODUTOADIC A
	    	JOIN PRODUTO P ON
	        	A.CDSUBPRODUTO = P.CDPRODUTO AND 
	        	P.NRORG = :NRORG
	    	JOIN PRODUTO PAI ON     
			    PAI.CDPRODUTO = A.CDPRODUTO AND
			    PAI.NRORG = :NRORG
			 JOIN PRODUTO AVO ON     
			    AVO.CDPRODUTO = :CDPRODUTO AND
			    AVO.NRORG = :NRORG   
			 JOIN FILIAL F ON 
	           F.CDFILIAL = :CDFILIAL AND
	           F.NRORG = :NRORG 
			 WHERE A.CDPRODUTO    = :CDPRODUTO
			   AND A.NRORG = :NRORG		   
			 ORDER BY A.IDMODOVENDA, P.CDARVPROD
	    ";
	    
		const GET_COMPARATIVO_PADRAO_LOCAL = "
            SELECT CP.LABELFILIAL, CP.PRODPRIN, CP.SUBPROD, CP.QTLOCAL, CP.QTPADR
              FROM (SELECT 'Padrão' AS LABELFILIAL, R.CDPRODUTO||' - '||P.NMPRODUTO AS PRODPRIN, R.CDSUBPRODUTO||' - '||SP.NMPRODUTO AS SUBPROD, 0 AS QTLOCAL, R.QTSUBPRODROT AS QTPADR
          			  FROM ROTFABRICA R
          			  JOIN PRODUTO P
          			    ON R.CDPRODUTO = P.CDPRODUTO
          			   AND R.NRORG = P.NRORG
          			  JOIN PRODUTO SP
          			    ON R.CDSUBPRODUTO = SP.CDPRODUTO
          			   AND R.NRORG = SP.NRORG
          			 WHERE ((((INSTR(:CDPRODLIST, SP.CDPRODUTO) > 0 ) OR (SP.CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN ))) OR (SP.CDARVPROD LIKE :PRODNIV) OR (:TCDPRODUTO = 'T'))
          			   AND R.NRORG = :NRORG
            			
          			  UNION
            			
          			SELECT RL.CDFILIAL||' - '||F.NMFILIAL AS LABELFILIAL, RL.CDPRODUTO||' - '||P.NMPRODUTO AS PRODPRINC, RL.CDSUBPRODLOC||' - '||SP.NMPRODUTO AS SUBPROD, RL.QTSUBPRODLOC AS QTLOCAL, NVL(RF.QTSUBPRODROT, 0) AS QTPADR
          			  FROM ROTFABLOCAL RL
                      LEFT JOIN ROTFABRICA RF
                        ON RL.CDPRODUTO = RF.CDPRODUTO
                       AND RL.CDSUBPRODLOC = RF.CDSUBPRODUTO
                       AND RL.NRORG = RF.NRORG
          			  JOIN PRODUTO P
          			    ON RL.CDPRODUTO = P.CDPRODUTO
          			   AND RL.NRORG = P.NRORG
          			  JOIN PRODUTO SP
          			    ON RL.CDSUBPRODLOC = SP.CDPRODUTO
          			   AND RL.NRORG = SP.NRORG
                      JOIN FILIAL F
                        ON RL.CDFILIAL = F.CDFILIAL
                       AND RL.NRORG = F.NRORG
          			 WHERE ((((INSTR(:CDPRODLIST, SP.CDPRODUTO) > 0 ) OR (SP.CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN ))) OR (SP.CDARVPROD LIKE :PRODNIV) OR (:TCDPRODUTO = 'T'))
          			   AND RL.CDFILIAL = :CDFILIAL
          			   AND RL.NRORG = :NRORG) CP
             ORDER BY 1, 2
		";
}