<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;

class RelMetaVersusVendasService {
	
	protected $entityManager;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	public function fetchReport($conditions){
	    $params = self::buildQueryParams($conditions);
	    try{
        $result = $this->entityManager->getConnection()->fetchAll(self::VENDAS_VERSUS_META_QRY, $params);
        $result = self::operateParameters($result, $params);  
	      return $result;
	    }catch (\Exception $e){
        throw $e;
     }
	}
	
	
	private function buildQueryParams($conditions){
    if(array_key_exists('CDFILIAL', $conditions)){
      $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
    }
    for($i = 0; $i < sizeof($conditions['MESDATA']); $i++){
      $conditions['MESDATA'][$i] = $conditions['MESDATA'][$i].'/'.$conditions['ANODATA'];
    }
    
    $conditions['DATA'] = implode('_', $conditions['MESDATA']);
    $params = array(
      ':NRORG'    => $conditions['NRORG'],
      ':CDFILIAL' => $conditions['CDFILIAL'],
      ':DATA'     => $conditions['DATA']
    );
   return $params;
  }
  
  private function operateParameters($result, $params){
	  foreach($result as &$rows){
	        $params['CDFILIAL']         = $rows['CDFILIAL'];
	        $rows['TOTAL_FATURAMENTO']  = floatval($rows['TOTAL_FATURAMENTO']);
	        $rows['MES']                = $rows['MES'];
	        $rows['ANO']                = $rows['ANO'] ;
          $rows['VRMES']              = floatval($rows['VRMES']);
	        $rows['CDANO']              = $rows['CDANO'];
	        $rows['NMMES']              = $rows['NMMES'];
	        $rows['NRORG']              = $rows['NRORG']; 
	        $rows['NMFILIAL']           = $rows['NMFILIAL'];
	        $rows['ANOMES']             = $rows['NMMES'].' de '.$rows['CDANO'];
	        $rows['VRMENOSMETA']        = floatval($rows['VRMENOSMETA']);
 	        $rows['PERCENTUAL']         = floatval($rows['PERCENTUAL']);
	    }
	   return $result;
	}
	
	const VENDAS_VERSUS_META_QRY = "
    SELECT FILOCAVE.CDFILIAL, FILOCAVE.NRORG, FILOCAVE.NMFILIAL,
      SUM(TRUNC(I.QTPRODVEND * ( NVL(I.VRUNITVEND, 0) + NVL(I.VRUNITVENDCL,0)), 2)) + FILOCAVE.VRTXENTREGA AS TOTAL_FATURAMENTO,              
      SUM(FILOCAVE.NRPESMESAVENDA) AS NRPESMESAVENDA, FILOCAVE.VRTXENTREGA, FILOCAVE.VRMES, TO_CHAR(DTENTRVENDA, 'MM') AS MES, TO_CHAR(DTENTRVENDA, 'YYYY') AS ANO,
      CASE FILOCAVE.CDMES 
        WHEN 1 THEN 'Janeiro'
        WHEN 2 THEN 'Fevereiro'
        WHEN 3 THEN 'Março'
        WHEN 4 THEN 'Abril'
        WHEN 5 THEN 'Maio'
        WHEN 6 THEN 'Junho'
        WHEN 7 THEN 'Julho'
        WHEN 8 THEN 'Agosto'
        WHEN 9 THEN 'Setembro'
        WHEN 10 THEN 'Outubro'
        WHEN 11 THEN 'Novembro'
        WHEN 12 THEN 'Dezembro'
      END AS NMMES, FILOCAVE.CDANO,
      (SUM(TRUNC(I.QTPRODVEND * ( NVL(I.VRUNITVEND, 0) + NVL(I.VRUNITVENDCL,0)), 2)) + FILOCAVE.VRTXENTREGA) - FILOCAVE.VRMES AS VRMENOSMETA,
      TRUNC(((SUM(TRUNC(I.QTPRODVEND * ( NVL(I.VRUNITVEND, 0) + NVL(I.VRUNITVENDCL,0)), 2)) + FILOCAVE.VRTXENTREGA)/(FILOCAVE.VRMES)*100),2) AS PERCENTUAL,
      TRUNC(((SUM(TRUNC(I.QTPRODVEND * ( NVL(I.VRUNITVEND, 0) + NVL(I.VRUNITVENDCL,0)), 2)) + FILOCAVE.VRTXENTREGA)/(SUM(FILOCAVE.NRPESMESAVENDA))),2)  AS TCKMED              
   FROM ITEMVENDA I
     JOIN ( SELECT FILOCAVE.NRSEQVENDA, FILOCAVE.CDCAIXA, FILOCAVE.NMCAIXA, FILOCAVE.CDLOJA, FILOCAVE.NMLOJA, FILOCAVE.CDFILIAL,
                FILOCAVE.DTVENDA, FILOCAVE.DTENTRVENDA, FILOCAVE.NMFILIAL, SUM(FILOCAVE.VRREPIQUEVENDA)  OVER (PARTITION BY FILOCAVE.CDFILIAL, FILOCAVE.DTENTRVENDA)  AS VRREPIQUEVENDA, FILOCAVE.DTABERVENDA,
                FILOCAVE.NRORG, SUM(FILOCAVE.NRPESMESAVENDA) OVER (PARTITION BY FILOCAVE.CDFILIAL,FILOCAVE.DTENTRVENDA) AS NRPESMESAVENDA,
                NVL(TXENTREGA.VRTXENTREGA, 0) AS VRTXENTREGA, TRUNC(FILOCAVE.VRMES, 2) AS VRMES, FILOCAVE.CDMES, FILOCAVE.CDANO
             FROM (SELECT V.IDSITUVENDA, V.NRSEQVENDA, V.DTVENDA, V.DTENTRVENDA, FILOCA.CDCAIXA, FILOCA.NMCAIXA, FILOCA.CDLOJA, FILOCA.NMLOJA, FILOCA.CDFILIAL,
                        FILOCA.NMFILIAL, NVL(V.VRREPIQUEVENDA, 0) AS VRREPIQUEVENDA, V.DTABERVENDA,
                        FILOCA.NRORG, NVL(V.NRPESMESAVENDA, 1) AS NRPESMESAVENDA, FILOCA.VRMES, FILOCA.CDMES, FILOCA.CDANO
                    FROM VENDA V
                    JOIN ( SELECT C.CDCAIXA, C.NMCAIXA, FILO.CDLOJA, FILO.NMLOJA, FILO.CDFILIAL, FILO.NMFILIAL, FILO.NRORG, FILO.CDMES, FILO.CDANO, FILO.VRMES
                             FROM CAIXA C
                             JOIN (SELECT L.CDLOJA, L.NMLOJA, L.CDPRODTAXASERV, FIPA.CDFILIAL, FIPA.NMFILIAL, FIPA.NRORG, FIPA.CDMES, FIPA.CDANO, FIPA.VRMES
                                     FROM LOJA L
                                     JOIN (SELECT FI.CDFILIAL, FI.NMFILIAL, FI.NRORG,  CASE ME.VRMES WHEN 0 THEN 1 ELSE ME.VRMES END AS VRMES, ME.CDMES, ME.CDANO, ME.IDATIVO
                                            FROM
                                              METAMES ME                                                  
                                             JOIN FILIAL FI
                                              ON ME.CDFILIAL = FI.CDFILIAL                                                 
                                            WHERE INSTR(:CDFILIAL, FI.CDFILIAL) > 0 
                                              AND ME.IDATIVO = 'S'
                                              AND FI.NRORG =:NRORG                                                   
                                          ) FIPA
                                       ON L.CDFILIAL = FIPA.CDFILIAL
                                        AND L.NRORG = FIPA.NRORG) FILO 
                               ON C.CDFILIAL = FILO.CDFILIAL 
                                AND C.CDLOJA = FILO.CDLOJA
                                AND C.NRORG = FILO.NRORG ) FILOCA 
                       ON V.CDCAIXA = FILOCA.CDCAIXA
                        AND V.CDLOJA = FILOCA.CDLOJA
                        AND V.CDFILIAL = FILOCA.CDFILIAL
                        AND FILOCA.CDMES = TO_NUMBER(TO_CHAR(V.DTENTRVENDA, 'MM'))
                        AND FILOCA.CDANO = TO_NUMBER(TO_CHAR(DTENTRVENDA, 'YYYY'))
                        AND V.NRORG = FILOCA.NRORG
                    WHERE V.IDSITUVENDA = 'O' 
                      AND  INSTR(:DATA, TO_CHAR(V.DTENTRVENDA, 'MM/YYYY')) > 0                          
                      ) FILOCAVE
             LEFT JOIN (SELECT V.CDFILIAL, TO_CHAR(V.DTENTRVENDA, 'MM') AS MES, TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO, NVL(SUM(NVL(I.VRACRITVEND,0))- SUM(NVL(V.VRREPIQUEVENDA,0)), 0) AS VRTXENTREGA
                     FROM ITEMVENDA I
                     JOIN LOJA L
                       ON I.CDPRODUTO   = L.CDPRODTAXAENTR
                        AND I.CDFILIAL    = L.CDFILIAL
                        AND I.NRORG = L.NRORG 
                     JOIN VENDA V
                       ON I.NRSEQVENDA  = V.NRSEQVENDA
                        AND I.CDFILIAL    = V.CDFILIAL
                        AND I.CDCAIXA     = V.CDCAIXA
                        AND L.CDLOJA      = V.CDLOJA
                        AND L.CDFILIAL      = V.CDFILIAL
                     JOIN PARAVEND P
                       ON I.CDFILIAL    = P.CDFILIAL
                    WHERE INSTR(:CDFILIAL, V.CDFILIAL) > 0    
                      AND L.IDTRATTAXAENTR = 'P'
                      AND SUBSTR(V.IDORIGEMVENDA, 0, 3) = 'DLV'    
                      AND I.NRORG = :NRORG
                      AND V.IDSITUVENDA = 'O'                          
                      AND INSTR(:DATA, TO_CHAR(V.DTENTRVENDA, 'MM/YYYY')) > 0
                    GROUP BY V.CDFILIAL, TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY') 
                  ) TXENTREGA                
              ON FILOCAVE.CDFILIAL = TXENTREGA.CDFILIAL
               AND FILOCAVE.CDMES = TXENTREGA.MES
               AND FILOCAVE.CDANO = TXENTREGA.ANO) FILOCAVE
       ON FILOCAVE.CDFILIAL = I.CDFILIAL
        AND FILOCAVE.NRORG = I.NRORG
        AND FILOCAVE.NRSEQVENDA = I.NRSEQVENDA
        AND FILOCAVE.CDCAIXA = I.CDCAIXA
  WHERE INSTR(:DATA, TO_CHAR(FILOCAVE.DTENTRVENDA, 'MM/YYYY')) > 0
    AND FILOCAVE.CDMES = TO_NUMBER(TO_CHAR(FILOCAVE.DTENTRVENDA, 'MM'))
    AND FILOCAVE.CDANO = TO_NUMBER(TO_CHAR(FILOCAVE.DTENTRVENDA, 'YYYY'))
  GROUP BY FILOCAVE.CDFILIAL, FILOCAVE.CDANO, FILOCAVE.CDMES, FILOCAVE.NRORG, FILOCAVE.NMFILIAL, FILOCAVE.VRMES, FILOCAVE.VRTXENTREGA, TO_CHAR(DTENTRVENDA, 'MM'), TO_CHAR(DTENTRVENDA, 'YYYY')
  ORDER BY FILOCAVE.CDFILIAL, FILOCAVE.CDANO, FILOCAVE.CDMES  
  ";
}